@@ -1,7 +1,7 @@
-/* $Id: rplay.c,v 1.3 1998/08/13 06:13:36 boyns Exp $ */
+/* $Id: rplay.c,v 1.6 1999/03/10 07:57:56 boyns Exp $ */
 
 /*
- * Copyright (C) 1993-98 Mark R. Boyns <boyns@doit.org>
+ * Copyright (C) 1993-99 Mark R. Boyns <boyns@doit.org>
  *
  * This file is part of rplay.
  *
@@ -20,8 +20,6 @@
  * Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
-
-
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -74,33 +72,33 @@ char *rplay_errlist[] =
     "unknown rplay modifier",	/* RPLAY_ERROR_MODIFIER */
 };
 /*
-#ifdef __STDC__
-unsigned long inet_addr (char *rp);
-#else
-unsigned long inet_addr ();
-#endif
-*/
+   #ifdef __STDC__
+   unsigned long inet_addr (char *rp);
+   #else
+   unsigned long inet_addr ();
+   #endif
+ */
 /* A simple version a strdup. */
 #ifndef HAVE_STRDUP
 #ifdef __STDC__
 static char *
-strdup (char *str)
+strdup(char *str)
 #else
 static char *
-strdup (str)
+strdup(str)
     char *str;
 #endif
 {
     char *p;
 
-    p = (char *) malloc (strlen (str) + 1);
+    p = (char *) malloc(strlen(str) + 1);
     if (p == NULL)
     {
 	return NULL;
     }
     else
     {
-	strcpy (p, str);
+	strcpy(p, str);
 	return p;
     }
 }
@@ -111,15 +109,15 @@ strdup (str)
  */
 #ifdef __STDC__
 static RPLAY_ATTRS *
-rplay_attrs_create (void)
+rplay_attrs_create(void)
 #else
 static RPLAY_ATTRS *
-rplay_attrs_create ()
+rplay_attrs_create()
 #endif
 {
     RPLAY_ATTRS *attrs;
 
-    attrs = (RPLAY_ATTRS *) malloc (sizeof (RPLAY_ATTRS));
+    attrs = (RPLAY_ATTRS *) malloc(sizeof(RPLAY_ATTRS));
     if (attrs == NULL)
     {
 	return NULL;
@@ -142,26 +140,26 @@ rplay_attrs_create ()
  */
 #ifdef __STDC__
 static void
-rplay_attrs_destroy (RPLAY_ATTRS *attrs)
+rplay_attrs_destroy(RPLAY_ATTRS *attrs)
 #else
 static void
-rplay_attrs_destroy (attrs)
+rplay_attrs_destroy(attrs)
     RPLAY_ATTRS *attrs;
 #endif
 {
     if (*attrs->sound)
     {
-	free ((char *) attrs->sound);
+	free((char *) attrs->sound);
     }
     if (attrs->rptp_server)
     {
-	free ((char *) attrs->rptp_server);
+	free((char *) attrs->rptp_server);
     }
     if (*attrs->client_data)
     {
-	free ((char *) attrs->client_data);
+	free((char *) attrs->client_data);
     }
-    free ((char *) attrs);
+    free((char *) attrs);
 }
 
 #define COPY_SIZE	128
@@ -196,10 +194,10 @@ rplay_attrs_destroy (attrs)
  */
 #ifdef __STDC__
 int
-rplay_pack (RPLAY *rp)
+rplay_pack(RPLAY *rp)
 #else
 int
-rplay_pack (rp)
+rplay_pack(rp)
     RPLAY *rp;
 #endif
 {
@@ -212,62 +210,62 @@ rplay_pack (rp)
 
     rp->len = 0;
     val = RPLAY_PACKET_ID;
-    COPY (rp, &val, sizeof (val));
+    COPY(rp, &val, sizeof(val));
     val = rp->command;
-    COPY (rp, &val, sizeof (val));
+    COPY(rp, &val, sizeof(val));
 
     if (rp->count != RPLAY_DEFAULT_LIST_COUNT)
     {
 	val = RPLAY_LIST_COUNT;
-	COPY (rp, &val, sizeof (val));
+	COPY(rp, &val, sizeof(val));
 	val = rp->count;
-	COPY (rp, &val, sizeof (val));
+	COPY(rp, &val, sizeof(val));
     }
 
     if (rp->priority != RPLAY_DEFAULT_PRIORITY)
     {
 	val = RPLAY_PRIORITY;
-	COPY (rp, &val, sizeof (val));
+	COPY(rp, &val, sizeof(val));
 	val = rp->priority;
-	COPY (rp, &val, sizeof (val));
+	COPY(rp, &val, sizeof(val));
     }
 
     if (*rp->list_name)
     {
 	val = RPLAY_LIST_NAME;
-	COPY (rp, &val, sizeof (val));
-	len = strlen (rp->list_name) + 1;
-	COPY (rp, rp->list_name, len);
+	COPY(rp, &val, sizeof(val));
+	len = strlen(rp->list_name) + 1;
+	COPY(rp, rp->list_name, len);
     }
 
     if (rp->id != RPLAY_NULL)
     {
 	val = RPLAY_ID;
-	COPY (rp, &val, sizeof (val));
-	val = rp->id;
-	COPY (rp, &val, sizeof (val));
+	COPY(rp, &val, sizeof(val));
+	lval = htonl(rp->id);
+	COPY(rp, &lval, sizeof(lval));
     }
 
     if (rp->sequence != -1)
     {
 	val = RPLAY_SEQUENCE;
-	COPY (rp, &val, sizeof (val));
-	lval = htonl (rp->sequence);
-	COPY (rp, &lval, sizeof (lval));
+	COPY(rp, &val, sizeof(val));
+	lval = htonl(rp->sequence);
+	COPY(rp, &lval, sizeof(lval));
     }
 
     if (rp->data != RPLAY_NULL && rp->data_size > 0)
     {
 	val = RPLAY_DATA_SIZE;
-	COPY (rp, &val, sizeof (val));
-	sval = htons (rp->data_size);
-	COPY (rp, &sval, sizeof (sval));
-	
+	COPY(rp, &val, sizeof(val));
+	sval = htons(rp->data_size);
+	COPY(rp, &sval, sizeof(sval));
+
 	val = RPLAY_DATA;
-	COPY (rp, &val, sizeof (val));
-	COPY (rp, rp->data, rp->data_size);
+	COPY(rp, &val, sizeof(val));
+	COPY(rp, rp->data, rp->data_size);
     }
-    
+
     for (i = 0, attrs = rp->attrs; attrs; attrs = attrs->next, i++)
     {
 	if (rp->random_sound != RPLAY_DEFAULT_RANDOM_SOUND)
@@ -281,79 +279,79 @@ rplay_pack (rp)
 	if (*attrs->sound)
 	{
 	    val = RPLAY_SOUND;
-	    COPY (rp, &val, sizeof (val));
-	    len = strlen (attrs->sound) + 1;
-	    COPY (rp, attrs->sound, len);
+	    COPY(rp, &val, sizeof(val));
+	    len = strlen(attrs->sound) + 1;
+	    COPY(rp, attrs->sound, len);
 	}
 
 	if (attrs->volume != RPLAY_DEFAULT_VOLUME)
 	{
 	    val = RPLAY_VOLUME;
-	    COPY (rp, &val, sizeof (val));
+	    COPY(rp, &val, sizeof(val));
 	    val = attrs->volume;
-	    COPY (rp, &val, sizeof (val));
+	    COPY(rp, &val, sizeof(val));
 	}
 
 	if (attrs->count != RPLAY_DEFAULT_COUNT)
 	{
 	    val = RPLAY_COUNT;
-	    COPY (rp, &val, sizeof (val));
+	    COPY(rp, &val, sizeof(val));
 	    val = attrs->count;
-	    COPY (rp, &val, sizeof (val));
+	    COPY(rp, &val, sizeof(val));
 	}
 
 	if (attrs->rptp_server)
 	{
 	    val = RPLAY_RPTP_SERVER;
-	    COPY (rp, &val, sizeof (val));
-	    len = strlen (attrs->rptp_server) + 1;
-	    COPY (rp, attrs->rptp_server, len);
+	    COPY(rp, &val, sizeof(val));
+	    len = strlen(attrs->rptp_server) + 1;
+	    COPY(rp, attrs->rptp_server, len);
 	}
 
 	if (attrs->rptp_server_port != RPTP_PORT)
 	{
 	    val = RPLAY_RPTP_SERVER_PORT;
-	    COPY (rp, &val, sizeof (val));
-	    size = htons (attrs->rptp_server_port);
-	    COPY (rp, &size, sizeof (size));
+	    COPY(rp, &val, sizeof(val));
+	    size = htons(attrs->rptp_server_port);
+	    COPY(rp, &size, sizeof(size));
 	}
 
 	if (attrs->rptp_search == FALSE)
 	{
 	    val = RPLAY_RPTP_SEARCH;
-	    COPY (rp, &val, sizeof (val));
+	    COPY(rp, &val, sizeof(val));
 	    val = attrs->rptp_search;
-	    COPY (rp, &val, sizeof (val));
+	    COPY(rp, &val, sizeof(val));
 	}
 
 	if (attrs->sample_rate != RPLAY_DEFAULT_SAMPLE_RATE)
 	{
 	    val = RPLAY_SAMPLE_RATE;
-	    COPY (rp, &val, sizeof (val));
-	    lval = htonl (attrs->sample_rate);
-	    COPY (rp, &lval, sizeof (lval));
+	    COPY(rp, &val, sizeof(val));
+	    lval = htonl(attrs->sample_rate);
+	    COPY(rp, &lval, sizeof(lval));
 	}
 
 	if (*attrs->client_data)
 	{
 	    val = RPLAY_CLIENT_DATA;
-	    COPY (rp, &val, sizeof (val));
-	    len = strlen (attrs->client_data) + 1;
-	    COPY (rp, attrs->client_data, len);
+	    COPY(rp, &val, sizeof(val));
+	    len = strlen(attrs->client_data) + 1;
+	    COPY(rp, attrs->client_data, len);
 	}
 
 	val = RPLAY_NULL;
-	COPY (rp, &val, sizeof (val));
+	COPY(rp, &val, sizeof(val));
     }
 
     if (i == 0)
     {
 	val = RPLAY_NULL;
-	COPY (rp, &val, sizeof (val));
+	COPY(rp, &val, sizeof(val));
     }
 
     val = RPLAY_NULL;
-    COPY (rp, &val, sizeof (val));
+    COPY(rp, &val, sizeof(val));
 
     return 0;
 }
@@ -363,10 +361,10 @@ rplay_pack (rp)
  */
 #ifdef __STDC__
 RPLAY *
-rplay_unpack (char *packet)
+rplay_unpack(char *packet)
 #else
 RPLAY *
-rplay_unpack (packet)
+rplay_unpack(packet)
     char *packet;
 #endif
 {
@@ -377,14 +375,14 @@ rplay_unpack (packet)
     rplay_errno = RPLAY_ERROR_NONE;
 
     version = *packet++;
-    rp = rplay_create (*packet++);
+    rp = rplay_create(*packet++);
     if (rp == NULL)
     {
 	rplay_errno = RPLAY_ERROR_MEMORY;
 	return NULL;
     }
 
-    *(rp->attrsp) = rplay_attrs_create ();
+    *(rp->attrsp) = rplay_attrs_create();
     if (*(rp->attrsp) == NULL)
     {
 	rplay_errno = RPLAY_ERROR_MEMORY;
@@ -400,17 +398,17 @@ rplay_unpack (packet)
 	    break;
 
 	case RPLAY_LIST_NAME:
-	    rp->list_name = strdup (packet);
-	    packet += strlen (packet) + 1;
+	    rp->list_name = strdup(packet);
+	    packet += strlen(packet) + 1;
 	    break;
-	    
+
 	case RPLAY_PRIORITY:
 	    rp->priority = (unsigned char) *packet++;
 	    break;
 
 	case RPLAY_SOUND:
-	    (*rp->attrsp)->sound = strdup (packet);
-	    packet += strlen (packet) + 1;
+	    (*rp->attrsp)->sound = strdup(packet);
+	    packet += strlen(packet) + 1;
 	    break;
 
 	case RPLAY_VOLUME:
@@ -422,14 +420,14 @@ rplay_unpack (packet)
 	    break;
 
 	case RPLAY_RPTP_SERVER:
-	    (*rp->attrsp)->rptp_server = strdup (packet);
-	    packet += strlen (packet) + 1;
+	    (*rp->attrsp)->rptp_server = strdup(packet);
+	    packet += strlen(packet) + 1;
 	    break;
 
 	case RPLAY_RPTP_SERVER_PORT:
-	    memcpy ((char *) &(*rp->attrsp)->rptp_server_port, packet, sizeof ((*rp->attrsp)->rptp_server_port));
-	    (*rp->attrsp)->rptp_server_port = ntohs ((*rp->attrsp)->rptp_server_port);
-	    packet += sizeof ((*rp->attrsp)->rptp_server_port);
+	    memcpy((char *) &(*rp->attrsp)->rptp_server_port, packet, sizeof((*rp->attrsp)->rptp_server_port));
+	    (*rp->attrsp)->rptp_server_port = ntohs((*rp->attrsp)->rptp_server_port);
+	    packet += sizeof((*rp->attrsp)->rptp_server_port);
 	    break;
 
 
@@ -438,38 +436,41 @@ rplay_unpack (packet)
 	    break;
 
 	case RPLAY_SAMPLE_RATE:
-	    memcpy ((char *) &(*rp->attrsp)->sample_rate, packet, sizeof ((*rp->attrsp)->sample_rate));
-	    (*rp->attrsp)->sample_rate = ntohl ((*rp->attrsp)->sample_rate);
-	    packet += sizeof ((*rp->attrsp)->sample_rate);
+	    memcpy((char *) &(*rp->attrsp)->sample_rate, packet,
+		   sizeof((*rp->attrsp)->sample_rate));
+	    (*rp->attrsp)->sample_rate = ntohl((*rp->attrsp)->sample_rate);
+	    packet += sizeof((*rp->attrsp)->sample_rate);
 	    break;
 
 	case RPLAY_CLIENT_DATA:
-	    (*rp->attrsp)->client_data = strdup (packet);
-	    packet += strlen (packet) + 1;
+	    (*rp->attrsp)->client_data = strdup(packet);
+	    packet += strlen(packet) + 1;
 	    break;
 
 	case RPLAY_ID:
-	    rp->id = (unsigned char) *packet++;
+	    memcpy((char *) &rp->id, packet, sizeof(rp->id));
+	    rp->id = ntohl(rp->id);
+	    packet += sizeof(rp->id);
 	    break;
 
 	case RPLAY_SEQUENCE:
-	    memcpy ((char *) &rp->sequence, packet, sizeof (rp->sequence));
-	    rp->sequence = ntohl (rp->sequence);
-	    packet += sizeof (rp->sequence);
+	    memcpy((char *) &rp->sequence, packet, sizeof(rp->sequence));
+	    rp->sequence = ntohl(rp->sequence);
+	    packet += sizeof(rp->sequence);
 	    break;
 
 	case RPLAY_DATA_SIZE:
-	    memcpy ((char *) &rp->data_size, packet, sizeof (rp->data_size));
-	    rp->data_size = ntohs (rp->data_size);
-	    packet += sizeof (rp->data_size);
+	    memcpy((char *) &rp->data_size, packet, sizeof(rp->data_size));
+	    rp->data_size = ntohs(rp->data_size);
+	    packet += sizeof(rp->data_size);
 	    break;
 
 	case RPLAY_DATA:
-	    rp->data = (char *) malloc (rp->data_size);
-	    memcpy (rp->data, packet, rp->data_size);
+	    rp->data = (char *) malloc(rp->data_size);
+	    memcpy(rp->data, packet, rp->data_size);
 	    packet += rp->data_size;
 	    break;
-	    
+
 	case RPLAY_NULL:
 	    rp->nsounds++;
 	    rp->attrsp = &(*rp->attrsp)->next;
@@ -479,7 +480,7 @@ rplay_unpack (packet)
 	    }
 	    else
 	    {
-		*(rp->attrsp) = rplay_attrs_create ();
+		*(rp->attrsp) = rplay_attrs_create();
 		if (*(rp->attrsp) == NULL)
 		{
 		    rplay_errno = RPLAY_ERROR_MEMORY;
@@ -491,7 +492,7 @@ rplay_unpack (packet)
 	default:
 	    rplay_errno = RPLAY_ERROR_ATTRIBUTE;
 #if 1
-	    printf ("unpack: unknown attr '%d'\n", *packet);
+	    printf("unpack: unknown attr '%d'\n", *packet);
 #endif
 	    return NULL;
 	}
@@ -508,10 +509,10 @@ rplay_unpack (packet)
  */
 #ifdef __STDC__
 RPLAY *
-rplay_create (int command)
+rplay_create(int command)
 #else
 RPLAY *
-rplay_create (command)
+rplay_create(command)
     int command;
 #endif
 {
@@ -519,7 +520,7 @@ rplay_create (command)
 
     rplay_errno = RPLAY_ERROR_NONE;
 
-    rp = (RPLAY *) malloc (sizeof (RPLAY));
+    rp = (RPLAY *) malloc(sizeof(RPLAY));
     if (rp == NULL)
     {
 	rplay_errno = RPLAY_ERROR_MEMORY;
@@ -528,7 +529,7 @@ rplay_create (command)
 
     rp->attrs = NULL;
     rp->attrsp = &rp->attrs;
-    rp->buf = (char *) malloc (COPY_SIZE);
+    rp->buf = (char *) malloc(COPY_SIZE);
     if (rp->buf == NULL)
     {
 	rplay_errno = RPLAY_ERROR_MEMORY;
@@ -547,7 +548,7 @@ rplay_create (command)
     rp->sequence = -1;
     rp->data = NULL;
     rp->data_size = 0;
-    
+
     switch (command)
     {
     case RPLAY_PLAY:
@@ -574,10 +575,10 @@ rplay_create (command)
  */
 #ifdef __STDC__
 static RPLAY_ATTRS *
-get_attrs (RPLAY_ATTRS *attrs, int index)
+get_attrs(RPLAY_ATTRS *attrs, int index)
 #else
 static RPLAY_ATTRS *
-get_attrs (attrs, index)
+get_attrs(attrs, index)
     RPLAY_ATTRS *attrs;
     int index;
 #endif
@@ -602,10 +603,10 @@ get_attrs (attrs, index)
  */
 #ifdef __STDC__
 long
-rplay_set (RPLAY *rp,...)
+rplay_set(RPLAY *rp,...)
 #else
 long
-rplay_set (va_alist)
+rplay_set(va_alist)
     va_dcl
 #endif
 {
@@ -616,21 +617,21 @@ rplay_set (va_alist)
     time_t seed;
 
 #ifdef __STDC__
-    va_start (args, rp);
+    va_start(args, rp);
 #else
     RPLAY *rp;
-    va_start (args);
-    rp = va_arg (args, RPLAY *);
+    va_start(args);
+    rp = va_arg(args, RPLAY *);
 #endif
 
     rplay_errno = RPLAY_ERROR_NONE;
 
-    modifier = va_arg (args, long);
+    modifier = va_arg(args, long);
 
     switch (modifier)
     {
     case RPLAY_APPEND:
-	*(rp->attrsp) = attrs = rplay_attrs_create ();
+	*(rp->attrsp) = attrs = rplay_attrs_create();
 	if (attrs == NULL)
 	{
 	    rplay_errno = RPLAY_ERROR_MEMORY;
@@ -641,7 +642,7 @@ rplay_set (va_alist)
 	break;
 
     case RPLAY_INSERT:
-	index = va_arg (args, long);
+	index = va_arg(args, long);
 	if (index < 0)
 	{
 	    rplay_errno = RPLAY_ERROR_INDEX;
@@ -657,7 +658,7 @@ rplay_set (va_alist)
 	    rplay_errno = RPLAY_ERROR_INDEX;
 	    return -1;
 	}
-	attrs = rplay_attrs_create ();
+	attrs = rplay_attrs_create();
 	if (attrs == NULL)
 	{
 	    rplay_errno = RPLAY_ERROR_MEMORY;
@@ -680,7 +681,7 @@ rplay_set (va_alist)
 	break;
 
     case RPLAY_DELETE:
-	index = va_arg (args, long);
+	index = va_arg(args, long);
 	if (index < 0)
 	{
 	    rplay_errno = RPLAY_ERROR_INDEX;
@@ -712,13 +713,13 @@ rplay_set (va_alist)
 		rp->attrsp = &rp->attrs;
 	    }
 	}
-	rplay_attrs_destroy (curr);
+	rplay_attrs_destroy(curr);
 	rp->nsounds--;
 	break;
 
     case RPLAY_CHANGE:
-	index = va_arg (args, long);
-	attrs = get_attrs (rp->attrs, index);
+	index = va_arg(args, long);
+	attrs = get_attrs(rp->attrs, index);
 	if (attrs == NULL)
 	{
 	    rplay_errno = RPLAY_ERROR_INDEX;
@@ -727,33 +728,33 @@ rplay_set (va_alist)
 	break;
 
     case RPLAY_LIST_COUNT:
-	rp->count = va_arg (args, long);
+	rp->count = va_arg(args, long);
 	break;
 
     case RPLAY_LIST_NAME:
 	if (*rp->list_name)
 	{
-	    free ((char *) rp->list_name);
+	    free((char *) rp->list_name);
 	}
-	rp->list_name = strdup (va_arg (args, char *));
+	rp->list_name = strdup(va_arg(args, char *));
 	break;
-	
+
     case RPLAY_PRIORITY:
-	rp->priority = va_arg (args, long);
+	rp->priority = va_arg(args, long);
 	break;
 
     case RPLAY_RANDOM_SOUND:
-	seed = time (0);
-	srandom ((int) seed);
-	rp->random_sound = (int) (random () % rp->nsounds);
+	seed = time(0);
+	srandom((int) seed);
+	rp->random_sound = (int) (random() % rp->nsounds);
 	break;
 
     case RPLAY_ID:
-	rp->id = va_arg (args, long);
+	rp->id = va_arg(args, long);
 	break;
 
     case RPLAY_SEQUENCE:
-	rp->sequence = va_arg (args, unsigned long);
+	rp->sequence = va_arg(args, unsigned long);
 	break;
 
     case RPLAY_DATA_SIZE:
@@ -763,20 +764,20 @@ rplay_set (va_alist)
     case RPLAY_DATA:
 	if (rp->data)
 	{
-	    free ((char *) rp->data);
+	    free((char *) rp->data);
 	}
 
-	data = va_arg (args, char *);
-	rp->data_size = va_arg (args, long);
-	rp->data = (char *) malloc (rp->data_size);
+	data = va_arg(args, char *);
+	rp->data_size = va_arg(args, long);
+	rp->data = (char *) malloc(rp->data_size);
 	if (rp->data == NULL)
 	{
 	    rplay_errno = RPLAY_ERROR_MEMORY;
 	    return -1;
 	}
-	memcpy (rp->data, data, rp->data_size);
+	memcpy(rp->data, data, rp->data_size);
 	break;
-	
+
     default:
 	rplay_errno = RPLAY_ERROR_MODIFIER;
 	return -1;
@@ -786,40 +787,40 @@ rplay_set (va_alist)
     {
 	int attribute;
 
-	while ((attribute = va_arg (args, long)))
+	while ((attribute = va_arg(args, long)))
 	{
 	    switch (attribute)
 	    {
 	    case RPLAY_LIST_COUNT:
-		rp->count = va_arg (args, long);
+		rp->count = va_arg(args, long);
 		break;
 
 	    case RPLAY_LIST_NAME:
 		if (*rp->list_name)
 		{
-		    free ((char *) rp->list_name);
+		    free((char *) rp->list_name);
 		}
-		rp->list_name = strdup (va_arg (args, char *));
+		rp->list_name = strdup(va_arg(args, char *));
 		break;
-	
+
 	    case RPLAY_PRIORITY:
-		rp->priority = va_arg (args, long);
+		rp->priority = va_arg(args, long);
 		break;
 
 	    case RPLAY_SOUND:
 		if (*attrs->sound)
 		{
-		    free ((char *) attrs->sound);
+		    free((char *) attrs->sound);
 		}
-		attrs->sound = strdup (va_arg (args, char *));
+		attrs->sound = strdup(va_arg(args, char *));
 		break;
 
 	    case RPLAY_VOLUME:
-		attrs->volume = va_arg (args, long);
+		attrs->volume = va_arg(args, long);
 		break;
 
 	    case RPLAY_COUNT:
-		attrs->count = va_arg (args, long);
+		attrs->count = va_arg(args, long);
 		break;
 
 	    case RPLAY_RPTP_SERVER:
@@ -828,12 +829,12 @@ rplay_set (va_alist)
 		    struct hostent *hp;
 		    u_long addr;
 		    struct sockaddr_in s;
-		    char *host = va_arg (args, char *);
+		    char *host = va_arg(args, char *);
 		    char hostname[MAXHOSTNAMELEN];
 
 		    if (attribute == RPLAY_RPTP_FROM_SENDER)
 		    {
-			if (gethostname (hostname, sizeof (hostname)) < 0)
+			if (gethostname(hostname, sizeof(hostname)) < 0)
 			{
 			    rplay_errno = RPLAY_ERROR_HOST;
 			    return -1;
@@ -842,49 +843,49 @@ rplay_set (va_alist)
 		    }
 		    else
 		    {
-			host = va_arg (args, char *);
+			host = va_arg(args, char *);
 		    }
 
-		    memset ((char *) &s, 0, sizeof (s));
-		    addr = inet_addr (host);
+		    memset((char *) &s, 0, sizeof(s));
+		    addr = inet_addr(host);
 		    if (addr == 0xffffffff)
 		    {
-			hp = gethostbyname (host);
+			hp = gethostbyname(host);
 			if (hp == NULL)
 			{
 			    rplay_errno = RPLAY_ERROR_HOST;
 			    return -1;
 			}
-			memcpy ((char *) &s.sin_addr.s_addr, (char *) hp->h_addr, hp->h_length);
+			memcpy((char *) &s.sin_addr.s_addr, (char *) hp->h_addr, hp->h_length);
 		    }
 		    else
 		    {
-			memcpy ((char *) &s.sin_addr.s_addr, (char *) &addr, sizeof (addr));
+			memcpy((char *) &s.sin_addr.s_addr, (char *) &addr, sizeof(addr));
 		    }
-		    attrs->rptp_server = strdup ((char *) inet_ntoa (s.sin_addr));
+		    attrs->rptp_server = strdup((char *) inet_ntoa(s.sin_addr));
 		    break;
 		}
 
 	    case RPLAY_RPTP_SERVER_PORT:
-		attrs->rptp_server_port = (unsigned short) va_arg (args, long);
+		attrs->rptp_server_port = (unsigned short) va_arg(args, long);
 		break;
 
 	    case RPLAY_RPTP_SEARCH:
-		attrs->rptp_search = va_arg (args, long);
+		attrs->rptp_search = va_arg(args, long);
 		break;
 
 	    case RPLAY_SAMPLE_RATE:
-		attrs->sample_rate = va_arg (args, unsigned long);
+		attrs->sample_rate = va_arg(args, unsigned long);
 		break;
 
 	    case RPLAY_CLIENT_DATA:
 		if (*attrs->client_data)
 		{
-		    free ((char *) attrs->client_data);
+		    free((char *) attrs->client_data);
 		}
-		attrs->client_data = strdup (va_arg (args, char *));
+		attrs->client_data = strdup(va_arg(args, char *));
 		break;
-		
+
 	    default:
 		rplay_errno = RPLAY_ERROR_ATTRIBUTE;
 		return -1;
@@ -892,7 +893,7 @@ rplay_set (va_alist)
 	}
     }
 
-    return rplay_pack (rp);
+    return rplay_pack(rp);
 }
 
 /*
@@ -900,10 +901,10 @@ rplay_set (va_alist)
  */
 #ifdef __STDC__
 long
-rplay_get (RPLAY *rp,...)
+rplay_get(RPLAY *rp,...)
 #else
 long
-rplay_get (va_alist)
+rplay_get(va_alist)
     va_dcl
 #endif
 {
@@ -912,15 +913,15 @@ rplay_get (va_alist)
     int get, index;
 
 #ifdef __STDC__
-    va_start (args, rp);
+    va_start(args, rp);
 #else
     RPLAY *rp;
-    va_start (args);
-    rp = va_arg (args, RPLAY *);
+    va_start(args);
+    rp = va_arg(args, RPLAY *);
 #endif
     rplay_errno = RPLAY_ERROR_NONE;
 
-    get = va_arg (args, long);
+    get = va_arg(args, long);
 
     switch (get)
     {
@@ -935,7 +936,7 @@ rplay_get (va_alist)
 
     case RPLAY_LIST_NAME:
 	return (long) rp->list_name;
-	
+
     case RPLAY_PRIORITY:
 	return rp->priority;
 
@@ -953,10 +954,10 @@ rplay_get (va_alist)
 
     case RPLAY_DATA:
 	return (long) rp->data;
-	
+
     case RPLAY_SOUND:
-	index = va_arg (args, long);
-	attrs = get_attrs (rp->attrs, index);
+	index = va_arg(args, long);
+	attrs = get_attrs(rp->attrs, index);
 	if (attrs == NULL)
 	{
 	    rplay_errno = RPLAY_ERROR_INDEX;
@@ -965,8 +966,8 @@ rplay_get (va_alist)
 	return (long) attrs->sound;
 
     case RPLAY_VOLUME:
-	index = va_arg (args, long);
-	attrs = get_attrs (rp->attrs, index);
+	index = va_arg(args, long);
+	attrs = get_attrs(rp->attrs, index);
 	if (attrs == NULL)
 	{
 	    rplay_errno = RPLAY_ERROR_INDEX;
@@ -975,8 +976,8 @@ rplay_get (va_alist)
 	return attrs->volume;
 
     case RPLAY_COUNT:
-	index = va_arg (args, long);
-	attrs = get_attrs (rp->attrs, index);
+	index = va_arg(args, long);
+	attrs = get_attrs(rp->attrs, index);
 	if (attrs == NULL)
 	{
 	    rplay_errno = RPLAY_ERROR_INDEX;
@@ -985,8 +986,8 @@ rplay_get (va_alist)
 	return attrs->count;
 
     case RPLAY_RPTP_SERVER:
-	index = va_arg (args, long);
-	attrs = get_attrs (rp->attrs, index);
+	index = va_arg(args, long);
+	attrs = get_attrs(rp->attrs, index);
 	if (attrs == NULL)
 	{
 	    rplay_errno = RPLAY_ERROR_INDEX;
@@ -995,8 +996,8 @@ rplay_get (va_alist)
 	return (long) attrs->rptp_server;
 
     case RPLAY_RPTP_SERVER_PORT:
-	index = va_arg (args, long);
-	attrs = get_attrs (rp->attrs, index);
+	index = va_arg(args, long);
+	attrs = get_attrs(rp->attrs, index);
 	if (attrs == NULL)
 	{
 	    rplay_errno = RPLAY_ERROR_INDEX;
@@ -1005,8 +1006,8 @@ rplay_get (va_alist)
 	return (long) attrs->rptp_server_port;
 
     case RPLAY_RPTP_SEARCH:
-	index = va_arg (args, long);
-	attrs = get_attrs (rp->attrs, index);
+	index = va_arg(args, long);
+	attrs = get_attrs(rp->attrs, index);
 	if (attrs == NULL)
 	{
 	    rplay_errno = RPLAY_ERROR_INDEX;
@@ -1015,8 +1016,8 @@ rplay_get (va_alist)
 	return attrs->rptp_search;
 
     case RPLAY_SAMPLE_RATE:
-	index = va_arg (args, long);
-	attrs = get_attrs (rp->attrs, index);
+	index = va_arg(args, long);
+	attrs = get_attrs(rp->attrs, index);
 	if (attrs == NULL)
 	{
 	    rplay_errno = RPLAY_ERROR_INDEX;
@@ -1025,15 +1026,15 @@ rplay_get (va_alist)
 	return attrs->sample_rate;
 
     case RPLAY_CLIENT_DATA:
-	index = va_arg (args, int);
-	attrs = get_attrs (rp->attrs, index);
+	index = va_arg(args, int);
+	attrs = get_attrs(rp->attrs, index);
 	if (attrs == NULL)
 	{
 	    rplay_errno = RPLAY_ERROR_INDEX;
 	    return -1;
 	}
 	return (long) attrs->client_data;
-	       
+
     default:
 	rplay_errno = RPLAY_ERROR_ATTRIBUTE;
 	return -1;
@@ -1045,10 +1046,10 @@ rplay_get (va_alist)
  */
 #ifdef __STDC__
 void
-rplay_destroy (RPLAY *rp)
+rplay_destroy(RPLAY *rp)
 #else
 void
-rplay_destroy (rp)
+rplay_destroy(rp)
     RPLAY *rp;
 #endif
 {
@@ -1056,17 +1057,17 @@ rplay_destroy (rp)
 
     rplay_errno = RPLAY_ERROR_NONE;
 
-    for (p = rp->attrs; p; q = p, p = p->next, rplay_attrs_destroy (q)) ;
+    for (p = rp->attrs; p; q = p, p = p->next, rplay_attrs_destroy(q)) ;
     if (*rp->list_name)
     {
-	free ((char *) rp->list_name);
+	free((char *) rp->list_name);
     }
     if (rp->data)
     {
-	free ((char *) rp->data);
+	free((char *) rp->data);
     }
-    free ((char *) rp->buf);
-    free ((char *) rp);
+    free((char *) rp->buf);
+    free((char *) rp);
 }
 
 /*
@@ -1075,10 +1076,10 @@ rplay_destroy (rp)
 #ifdef OLD_RPLAY
 #ifdef __STDC__
 char *
-rplay_convert (char *p)
+rplay_convert(char *p)
 #else
 char *
-rplay_convert (p)
+rplay_convert(p)
     char *p;
 #endif
 {
@@ -1109,8 +1110,8 @@ rplay_convert (p)
     do
     {
 	*q++ = RPLAY_SOUND;
-	strcpy (q, p);
-	len = strlen (p) + 1;
+	strcpy(q, p);
+	len = strlen(p) + 1;
 	p += len;
 	q += len;
 	*q++ = RPLAY_VOLUME;
@@ -1126,15 +1127,15 @@ rplay_convert (p)
 #endif /* OLD_RPLAY */
 
 static int
-default_rplay_port ()
+default_rplay_port()
 {
     struct servent *sp;
     int port;
 
-    sp = getservbyname ("rplay", "udp");
+    sp = getservbyname("rplay", "udp");
     if (sp)
     {
-	port = ntohs (sp->s_port);	/* htons is used later */
+	port = ntohs(sp->s_port);	/* htons is used later */
     }
     else
     {
@@ -1146,18 +1147,18 @@ default_rplay_port ()
 
 #ifdef __STDC__
 int
-rplay_open (char *host)
+rplay_open(char *host)
 #else
 int
-rplay_open (host)
+rplay_open(host)
     char *host;
 #endif
 {
     int port;
 
-    port = default_rplay_port ();
+    port = default_rplay_port();
 
-    return rplay_open_port (host, port);
+    return rplay_open_port(host, port);
 }
 
 /*
@@ -1167,10 +1168,10 @@ rplay_open (host)
  */
 #ifdef __STDC__
 int
-rplay_open_port (char *host, int port)
+rplay_open_port(char *host, int port)
 #else
 int
-rplay_open_port (host, port)
+rplay_open_port(host, port)
     char *host;
     int port;
 #endif
@@ -1181,43 +1182,43 @@ rplay_open_port (host, port)
 
     rplay_errno = RPLAY_ERROR_NONE;
 
-    memset ((char *) &s, 0, sizeof (s));
+    memset((char *) &s, 0, sizeof(s));
 
-    addr = inet_addr (host);
+    addr = inet_addr(host);
     if (addr == 0xffffffff)
     {
-	hp = gethostbyname (host);
+	hp = gethostbyname(host);
 	if (hp == NULL)
 	{
 	    rplay_errno = RPLAY_ERROR_HOST;
 	    return -1;
 	}
-	memcpy ((char *) &s.sin_addr.s_addr, (char *) hp->h_addr, hp->h_length);
+	memcpy((char *) &s.sin_addr.s_addr, (char *) hp->h_addr, hp->h_length);
     }
     else
     {
-	memcpy ((char *) &s.sin_addr.s_addr, (char *) &addr, sizeof (addr));
+	memcpy((char *) &s.sin_addr.s_addr, (char *) &addr, sizeof(addr));
     }
 
-    s.sin_port = htons (port);
+    s.sin_port = htons(port);
     s.sin_family = AF_INET;
 
-    return rplay_open_sockaddr_in (&s);
+    return rplay_open_sockaddr_in(&s);
 }
 
 #ifdef __STDC__
 int
-rplay_open_sockaddr_in (struct sockaddr_in *saddr)
+rplay_open_sockaddr_in(struct sockaddr_in *saddr)
 #else
 int
-rplay_open_sockaddr_in (saddr)
+rplay_open_sockaddr_in(saddr)
     struct sockaddr_in *saddr;
 #endif
 {
     int rplay_fd;
     int on = 1;
 
-    rplay_fd = socket (AF_INET, SOCK_DGRAM, 0);
+    rplay_fd = socket(AF_INET, SOCK_DGRAM, 0);
     if (rplay_fd < 0)
     {
 	rplay_errno = RPLAY_ERROR_SOCKET;
@@ -1227,13 +1228,13 @@ rplay_open_sockaddr_in (saddr)
     /*
      * enable broadcasting
      */
-    if (setsockopt (rplay_fd, SOL_SOCKET, SO_BROADCAST, (char *) &on, sizeof (on)) < 0)
+    if (setsockopt(rplay_fd, SOL_SOCKET, SO_BROADCAST, (char *) &on, sizeof(on)) < 0)
     {
 	rplay_errno = RPLAY_ERROR_BROADCAST;
 	return -1;
     }
 
-    if (connect (rplay_fd, (struct sockaddr *) saddr, sizeof (*saddr)) < 0)
+    if (connect(rplay_fd, (struct sockaddr *) saddr, sizeof(*saddr)) < 0)
     {
 	rplay_errno = RPLAY_ERROR_CONNECT;
 	return -1;
@@ -1247,17 +1248,17 @@ rplay_open_sockaddr_in (saddr)
  */
 #ifdef __STDC__
 int
-rplay (int rplay_fd, RPLAY *rp)
+rplay(int rplay_fd, RPLAY *rp)
 #else
 int
-rplay (rplay_fd, rp)
+rplay(rplay_fd, rp)
     int rplay_fd;
     RPLAY *rp;
 #endif
 {
     rplay_errno = RPLAY_ERROR_NONE;
 
-    if (write (rplay_fd, rp->buf, rp->len) != rp->len)
+    if (write(rplay_fd, rp->buf, rp->len) != rp->len)
     {
 	rplay_errno = RPLAY_ERROR_WRITE;
 	return -1;
@@ -1271,16 +1272,16 @@ rplay (rplay_fd, rp)
  */
 #ifdef __STDC__
 int
-rplay_close (int rplay_fd)
+rplay_close(int rplay_fd)
 #else
 int
-rplay_close (rplay_fd)
+rplay_close(rplay_fd)
     int rplay_fd;
 #endif
 {
     rplay_errno = RPLAY_ERROR_NONE;
 
-    if (close (rplay_fd) < 0)
+    if (close(rplay_fd) < 0)
     {
 	rplay_errno = RPLAY_ERROR_CLOSE;
 	return -1;
@@ -1294,14 +1295,14 @@ rplay_close (rplay_fd)
  */
 #ifdef __STDC__
 void
-rplay_perror (char *s)
+rplay_perror(char *s)
 #else
 void
-rplay_perror (s)
+rplay_perror(s)
     char *s;
 #endif
 {
-    fprintf (stderr, "%s: %s\n", s, rplay_errlist[rplay_errno]);
+    fprintf(stderr, "%s: %s\n", s, rplay_errlist[rplay_errno]);
 }
 
 /*
@@ -1310,35 +1311,35 @@ rplay_perror (s)
  */
 #ifdef __STDC__
 int
-rplay_open_display (void)
+rplay_open_display(void)
 #else
 int
-rplay_open_display ()
+rplay_open_display()
 #endif
 {
     char *display, *p;
     char host[MAXHOSTNAMELEN];
 
-    display = getenv ("DISPLAY");
+    display = getenv("DISPLAY");
     if (display == NULL || display[0] == ':')
     {
-	strcpy (host, "localhost");
+	strcpy(host, "localhost");
     }
     else
     {
-	strcpy (host, display);
-	p = strchr (host, ':');
+	strcpy(host, display);
+	p = strchr(host, ':');
 	if (p)
 	{
 	    *p = '\0';
 	}
-	if (strcmp (host, "unix") == 0 || strcmp (host, "local") == 0 || strcmp (host, "X") == 0)
+	if (strcmp(host, "unix") == 0 || strcmp(host, "local") == 0 || strcmp(host, "X") == 0)
 	{
-	    strcpy (host, "localhost");
+	    strcpy(host, "localhost");
 	}
     }
 
-    return rplay_open (host);
+    return rplay_open(host);
 }
 
 /*
@@ -1346,22 +1347,22 @@ rplay_open_display ()
  */
 #ifdef __STDC__
 int
-rplay_display (char *sound)
+rplay_display(char *sound)
 #else
 int
-rplay_display (sound)
+rplay_display(sound)
     char *sound;
 #endif
 {
     int rplay_fd;
 
-    rplay_fd = rplay_open_display ();
+    rplay_fd = rplay_open_display();
     if (rplay_fd < 0)
     {
 	return -1;
     }
 
-    return rplay_sound (rplay_fd, sound);
+    return rplay_sound(rplay_fd, sound);
 }
 
 /*
@@ -1369,14 +1370,14 @@ rplay_display (sound)
  */
 #ifdef __STDC__
 int
-rplay_local (char *sound)
+rplay_local(char *sound)
 #else
 int
-rplay_local (sound)
+rplay_local(sound)
     char *sound;
 #endif
 {
-    return rplay_host ("localhost", sound);
+    return rplay_host("localhost", sound);
 }
 
 /*
@@ -1384,23 +1385,23 @@ rplay_local (sound)
  */
 #ifdef __STDC__
 int
-rplay_host (char *host, char *sound)
+rplay_host(char *host, char *sound)
 #else
 int
-rplay_host (host, sound)
+rplay_host(host, sound)
     char *host;
     char *sound;
 #endif
 {
     int rplay_fd;
 
-    rplay_fd = rplay_open (host);
+    rplay_fd = rplay_open(host);
     if (rplay_fd < 0)
     {
 	return -1;
     }
 
-    return rplay_sound (rplay_fd, sound);
+    return rplay_sound(rplay_fd, sound);
 }
 
 /*
@@ -1408,33 +1409,33 @@ rplay_host (host, sound)
  */
 #ifdef __STDC__
 int
-rplay_sound (int rplay_fd, char *sound)
+rplay_sound(int rplay_fd, char *sound)
 #else
 int
-rplay_sound (rplay_fd, sound)
+rplay_sound(rplay_fd, sound)
     int rplay_fd;
     char *sound;
 #endif
 {
     RPLAY *rp;
 
-    rp = rplay_create (RPLAY_PLAY);
+    rp = rplay_create(RPLAY_PLAY);
     if (rp == NULL)
     {
 	return -1;
     }
 
-    if (rplay_set (rp, RPLAY_APPEND, RPLAY_SOUND, sound, NULL) < 0)
+    if (rplay_set(rp, RPLAY_APPEND, RPLAY_SOUND, sound, NULL) < 0)
     {
 	return -1;
     }
 
-    if (rplay (rplay_fd, rp) < 0)
+    if (rplay(rplay_fd, rp) < 0)
     {
 	return -1;
     }
 
-    rplay_destroy (rp);
+    rplay_destroy(rp);
 
     return 0;
 }
@@ -1444,10 +1445,10 @@ rplay_sound (rplay_fd, sound)
  */
 #ifdef __STDC__
 int
-rplay_ping (char *host)
+rplay_ping(char *host)
 #else
 int
-rplay_ping (host)
+rplay_ping(host)
     char *host;
 #endif
 {
@@ -1456,13 +1457,13 @@ rplay_ping (host)
     int error1 = 0, error2 = 0;
 
     /* Ping the default port.  */
-    port = default_rplay_port ();
-    rplay_fd = rplay_open_port (host, port);
+    port = default_rplay_port();
+    rplay_fd = rplay_open_port(host, port);
     if (rplay_fd < 0)
     {
 	return -1;
     }
-    error1 = rplay_ping_sockfd (rplay_fd);
+    error1 = rplay_ping_sockfd(rplay_fd);
 
 #ifdef OTHER_RPLAY_PORTS
     /* Pick an alternative port.  */
@@ -1476,12 +1477,12 @@ rplay_ping (host)
     }
 
     /* Ping the alternative port.  */
-    rplay_fd = rplay_open_port (host, port);
+    rplay_fd = rplay_open_port(host, port);
     if (rplay_fd < 0)
     {
 	return -1;
     }
-    error2 = rplay_ping_sockfd (rplay_fd);
+    error2 = rplay_ping_sockfd(rplay_fd);
 #endif /* OTHER_RPLAY_PORTS */
 
     /* Only return -1 if both pings fail. */
@@ -1497,55 +1498,55 @@ rplay_ping (host)
 
 #ifdef __STDC__
 int
-rplay_ping_sockfd (int rplay_fd)
+rplay_ping_sockfd(int rplay_fd)
 #else
 int
-rplay_ping_sockfd (rplay_fd)
+rplay_ping_sockfd(rplay_fd)
     int rplay_fd;
 #endif
 {
     RPLAY *rp;
 
-    rp = rplay_create (RPLAY_PING);
+    rp = rplay_create(RPLAY_PING);
     if (rp == NULL)
     {
 	return -1;
     }
 
-    if (rplay_pack (rp) < 0)
+    if (rplay_pack(rp) < 0)
     {
 	return -1;
     }
 
-    if (rplay (rplay_fd, rp) < 0)
+    if (rplay(rplay_fd, rp) < 0)
     {
 	return -1;
     }
 
-    rplay_close (rplay_fd);
-    rplay_destroy (rp);
+    rplay_close(rplay_fd);
+    rplay_destroy(rp);
 
     return 0;
 }
 
 #ifdef __STDC__
 int
-rplay_ping_sockaddr_in (struct sockaddr_in *saddr)
+rplay_ping_sockaddr_in(struct sockaddr_in *saddr)
 #else
 int
-rplay_ping_sockaddr_in (saddr)
+rplay_ping_sockaddr_in(saddr)
     struct sockaddr_in *saddr;
 #endif
 {
     int rplay_fd;
 
-    rplay_fd = rplay_open_sockaddr_in (saddr);
+    rplay_fd = rplay_open_sockaddr_in(saddr);
     if (rplay_fd < 0)
     {
 	return -1;
     }
 
-    return rplay_ping_sockfd (rplay_fd);
+    return rplay_ping_sockfd(rplay_fd);
 }
 
 /*
@@ -1553,10 +1554,10 @@ rplay_ping_sockaddr_in (saddr)
  */
 #ifdef __STDC__
 int
-rplay_host_volume (char *host, char *sound, int volume)
+rplay_host_volume(char *host, char *sound, int volume)
 #else
 int
-rplay_host_volume (host, sound, volume)
+rplay_host_volume(host, sound, volume)
     char *host;
     char *sound;
     int volume;
@@ -1565,29 +1566,29 @@ rplay_host_volume (host, sound, volume)
     int rplay_fd;
     RPLAY *rp;
 
-    rplay_fd = rplay_open (host);
+    rplay_fd = rplay_open(host);
     if (rplay_fd < 0)
     {
 	return -1;
     }
 
-    rp = rplay_create (RPLAY_PLAY);
+    rp = rplay_create(RPLAY_PLAY);
     if (rp == NULL)
     {
 	return -1;
     }
 
-    if (rplay_set (rp, RPLAY_APPEND, RPLAY_SOUND, sound, RPLAY_VOLUME, volume, NULL) < 0)
+    if (rplay_set(rp, RPLAY_APPEND, RPLAY_SOUND, sound, RPLAY_VOLUME, volume, NULL) < 0)
     {
 	return -1;
     }
 
-    if (rplay (rplay_fd, rp) < 0)
+    if (rplay(rplay_fd, rp) < 0)
     {
 	return -1;
     }
 
-    rplay_destroy (rp);
+    rplay_destroy(rp);
 
     return 0;
 }
@@ -1597,15 +1598,15 @@ rplay_host_volume (host, sound, volume)
  */
 #ifdef __STDC__
 char *
-rplay_default_host (void)
+rplay_default_host(void)
 #else
 char *
-rplay_default_host ()
+rplay_default_host()
 #endif
 {
     char *host;
 
-    host = getenv ("RPLAY_HOST");
+    host = getenv("RPLAY_HOST");
 
     return host ? host : "localhost";
 }
@@ -1615,14 +1616,14 @@ rplay_default_host ()
  */
 #ifdef __STDC__
 int
-rplay_default (char *sound)
+rplay_default(char *sound)
 #else
 int
-rplay_default (sound)
+rplay_default(sound)
     char *sound;
 #endif
 {
-    return rplay_host (rplay_default_host (), sound);
+    return rplay_host(rplay_default_host(), sound);
 }
 
 /*
@@ -1630,11 +1631,11 @@ rplay_default (sound)
  */
 #ifdef __STDC__
 int
-rplay_open_default (void)
+rplay_open_default(void)
 #else
 int
-rplay_open_default ()
+rplay_open_default()
 #endif
 {
-    return rplay_open (rplay_default_host ());
+    return rplay_open(rplay_default_host());
 }
