@@ -1,30 +1,30 @@
-# $Id: RPlay.pm,v 1.2 1998/08/13 06:18:06 boyns Exp $	-*-perl-*-
+# $Id: RPlay.pm,v 1.4 1999/06/10 05:39:06 boyns Exp $	-*-perl-*-
 #
-# Copyright (C) 1993-98 Mark R. Boyns <boyns@doit.org>                               
+# Copyright (C) 1993-98 Mark R. Boyns <boyns@doit.org>
 #
-# This file is part of rplay.                                                        
+# This file is part of rplay.
 #
-# rplay is free software; you can redistribute it and/or modify                      
-# it under the terms of the GNU General Public License as published by               
-# the Free Software Foundation; either version 2 of the License, or                  
-# (at your option) any later version.                                                
+# rplay is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
-# rplay is distributed in the hope that it will be useful,                           
-# but WITHOUT ANY WARRANTY; without even the implied warranty of                     
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                      
-# GNU General Public License for more details.                                       
+# rplay is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License                  
-# along with rplay; see the file COPYING.  If not, write to the                      
-# Free Software Foundation, Inc.,                                                    
-# 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.                            
+# You should have received a copy of the GNU General Public License
+# along with rplay; see the file COPYING.  If not, write to the
+# Free Software Foundation, Inc.,
+# 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 #
 
+require "rplay.ph";
+require 5.000;
+
 package RPlay;
 
-require 5.000;
-require "rplay.ph";
-
 use Socket;
 
 $connected = 0;
@@ -55,7 +55,7 @@ sub connect
 
     if (!$that_port)
     {
-	$that_port = $name ? $port : &RPLAY_PORT;
+	$that_port = $name ? $port : &main::RPLAY_PORT;
     }
 
     chop ($this_host = `hostname`);
@@ -82,7 +82,7 @@ sub connect
 sub disconnect
 {
     my $self = shift;
-    
+
     close (RPLAY);
     $connected = 0;
 }
@@ -130,12 +130,12 @@ sub doit
     my $self = shift;
     my $command = shift;
     my @refs = $self->parse (@_);
-    my (%attrs, $name, $packet);
+    my (%attrs, $name, $packet, $data_size, $data);
 
     die "Not connected - use connect () first." unless $connected;
 
     ## Packet header.
-    $packet = pack ("C", &RPLAY_PACKET_ID);
+    $packet = pack ("C", &main::RPLAY_PACKET_ID);
     $packet .= pack ("C", $command);
 
     ## Convert name-value hash pairs to RPLAY attributes.
@@ -143,7 +143,7 @@ sub doit
     {
     	%attrs = %$_;
 
-	if (!$attrs{'sound'})
+	if (!$attrs{'sound'} && $command ne &main::RPLAY_PUT)
 	{
 	    die "Missing `sound' attribute.";
 	}
@@ -151,42 +151,69 @@ sub doit
 	{
 	    if (/sound/)
 	    {
-		$packet .= pack ("C", &RPLAY_SOUND);
+		$packet .= pack ("C", &main::RPLAY_SOUND);
 		$packet .= "$attrs{$_}\0";
 	    }
 	    elsif (/volume/)
 	    {
-		$packet .= pack ("C", &RPLAY_VOLUME);
+		$packet .= pack ("C", &main::RPLAY_VOLUME);
 		$packet .= pack ("C", $attrs{$_});
 	    }
 	    elsif (/list_count/)
 	    {
-		$packet .= pack ("C", &RPLAY_LIST_COUNT);
+		$packet .= pack ("C", &main::RPLAY_LIST_COUNT);
 		$packet .= pack ("C", $attrs{$_});
 	    }
 	    elsif (/priority/)
 	    {
-		$packet .= pack ("C", &RPLAY_PRIORITY);
+		$packet .= pack ("C", &main::RPLAY_PRIORITY);
 		$packet .= pack ("C", $attrs{$_});
 	    }
 	    elsif (/sample_rate/)
 	    {
-		$packet .= pack ("C", &RPLAY_SAMPLE_RATE);
-		$packet .= pack ("C", $attrs{$_});
+		$packet .= pack ("C", &main::RPLAY_SAMPLE_RATE);
+		$packet .= pack ("N", $attrs{$_});
 	    }
 	    elsif (/list_name/)
 	    {
-		$packet .= pack ("C", &RPLAY_CLIENT_DATA);
+		$packet .= pack ("C", &main::RPLAY_LIST_NAME);
 		$packet .= "$attrs{$_}\0";
 	    }
+	    elsif (/id/)
+	    {
+		$packet .= pack ("C", &main::RPLAY_ID);
+		$packet .= pack ("N", $attrs{$_});
+	    }
+	    elsif (/sequence/)
+	    {
+		$packet .= pack ("C", &main::RPLAY_SEQUENCE);
+		$packet .= pack ("N", $attrs{$_});
+	    }
+	    elsif (/data_size/)
+	    {
+		$data_size = $attrs{$_};
+	    }
+	    elsif (/data/)
+	    {
+		$data = $attrs{$_};
+	    }
 	    else
 	    {
 		#warn "Uknown attribute `$_'";
 	    }
 	}
-        $packet .= pack ("C", &RPLAY_NULL);
+
+	if ($data && $data_size)
+	{
+	    $packet .= pack ("C", &main::RPLAY_DATA_SIZE);
+	    $packet .= pack ("n", $data_size);
+	    $packet .= pack ("C", &main::RPLAY_DATA);
+	    $packet .= $data;
+	}
+
+        $packet .= pack ("C", &main::RPLAY_NULL);
     }
-    $packet .= pack ("C", &RPLAY_NULL);
+    $packet .= pack ("C", &main::RPLAY_NULL);
 
     send (RPLAY, $packet, 0) || die "send: $!";
 }
@@ -195,35 +222,41 @@ sub doit
 sub play
 {
     my $self = shift;
-    $self->doit (&RPLAY_PLAY, @_);
+    $self->doit (&main::RPLAY_PLAY, @_);
 }
 
 ## Pause sounds.
 sub pause
 {
     my $self = shift;
-    $self->doit (&RPLAY_PAUSE, @_);
+    $self->doit (&main::RPLAY_PAUSE, @_);
 }
 
 ## Continue sounds.
 sub continue
 {
     my $self = shift;
-    $self->doit (&RPLAY_CONTINUE, @_);
+    $self->doit (&main::RPLAY_CONTINUE, @_);
 }
 
 ## Stop sounds.
 sub stop
 {
     my $self = shift;
-    $self->doit (&RPLAY_STOP, @_);
+    $self->doit (&main::RPLAY_STOP, @_);
 }
 
 ## Done sounds.
 sub done
 {
     my $self = shift;
-    $self->doit (&RPLAY_DONE, @_);
+    $self->doit (&main::RPLAY_DONE, @_);
+}
+
+sub put
+{
+    my $self = shift;
+    $self->doit (&main::RPLAY_PUT, @_);
 }
 
 1;
