@@ -1,7 +1,7 @@
-/* $Id: sound.h,v 1.2 1998/08/13 06:14:06 boyns Exp $ */
+/* $Id: sound.h,v 1.4 1999/06/09 06:27:44 boyns Exp $ */
 
 /*
- * Copyright (C) 1993-98 Mark R. Boyns <boyns@doit.org>
+ * Copyright (C) 1993-99 Mark R. Boyns <boyns@doit.org>
  *
  * This file is part of rplay.
  *
@@ -38,7 +38,15 @@
 #include "g72x.h"    
 #endif /* HAVE_ADPCM */
 #ifdef HAVE_GSM
-#include "gsm.h"    
+#ifdef HAVE_GSM_GSM_H
+#include <gsm/gsm.h>
+#else
+#ifdef HAVE_GSM_H
+#include <gsm.h>
+#else
+#include "gsm.h"
+#endif
+#endif
 #endif /* HAVE_GSM */
 
 #undef NUMBER_OF_SAMPLES
